/*****************************************************************************
 * Copyright (C) 2014-2018
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of BrewCloud
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/


function createDelElements() {
	$('#eventWindow').jqxWindow({
		theme: theme,
		position: { x: 490, y: 210 },
		width: 300,
		height: 145,
		resizable: false,
		isModal: true,
		modalOpacity: 0.4,
		okButton: $('#delOk'),
		cancelButton: $('#delCancel'),
		initContent: function () {
			$('#delOk').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').focus();
		}
	});
	$('#eventWindow').jqxWindow('hide');
}


$(document).ready(function () {
	var url = "includes/db_inventory_styles.php";
	// prepare the data
	var source = {
		datatype: "json",
		cache: false,
		datafields: [
			{ name: 'record', type: 'number' },
			{ name: 'name', type: 'string' },
			{ name: 'category', type: 'string' },
			{ name: 'category_number', type: 'number' },
			{ name: 'style_letter', type: 'string' },
			{ name: 'style_guide', type: 'string' },
			{ name: 'type', type: 'string' },
			{ name: 'og_min', type: 'float' },
			{ name: 'og_max', type: 'float' },
			{ name: 'fg_min', type: 'float' },
                        { name: 'fg_max', type: 'float' },
			{ name: 'ibu_min', type: 'float' },
                        { name: 'ibu_max', type: 'float' },
			{ name: 'color_min', type: 'float' },
			{ name: 'color_max', type: 'float' },
			{ name: 'carb_min', type: 'float' },
	                { name: 'carb_max', type: 'float' },
			{ name: 'abv_min', type: 'float' },
	                { name: 'abv_max', type: 'float' },
			{ name: 'notes', type: 'string' },
			{ name: 'profile', type: 'string' },
			{ name: 'ingredients', type: 'string' },
			{ name: 'examples', type: 'string' }
		],
		id: 'record',
		url: url,
		deleterow: function (rowid, commit) {
			// synchronize with the server - send delete command
			var data = "delete=true&" + $.param({ record: rowid });
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// delete command is executed.
					commit(true);
				},
				error: function (jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		},
		addrow: function (rowid, rowdata, position, commit) {
			var data = "insert=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
                                        commit(false);
                                }
                        });
                },
		updaterow: function (rowid, rowdata, commit) {
			var data = "update=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// update command is executed.
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		}
	};
	var srcType = [ "Lager", "Ale", "Mead", "Wheat", "Mixed", "Cider" ];
	// initialize the input fields.
	$("#name").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#category").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#category_number").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 1000, decimalDigits: 0, spinButtons: true });
	$("#style_letter").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#style_guide").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#type").jqxDropDownList({ theme: theme, source: srcType, width: 90, height: 23, dropDownHeight: 185 });
	$("#og_min").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 1.000, max: 1.200, decimalDigits: 3, spinButtons: true, spinButtonsStep: 0.001 });
	$("#og_max").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 1.000, max: 1.200, decimalDigits: 3, spinButtons: true, spinButtonsStep: 0.001 });
	$("#fg_min").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0.990, max: 1.100, decimalDigits: 3, spinButtons: true, spinButtonsStep: 0.001 });
	$("#fg_max").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 1.000, max: 1.100, decimalDigits: 3, spinButtons: true, spinButtonsStep: 0.001 });
	$("#ibu_min").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 200, decimalDigits: 0, spinButtons: true });
	$("#ibu_max").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 200, decimalDigits: 0, spinButtons: true });
	$("#color_min").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 1, max: 200, decimalDigits: 0, spinButtons: true });
	$("#color_max").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 1, max: 200, decimalDigits: 0, spinButtons: true });
	$("#carb_min").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 5, decimalDigits: 1, spinButtons: true, spinButtonsStep: 0.1 });
	$("#carb_max").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 5, decimalDigits: 1, spinButtons: true, spinButtonsStep: 0.1 });
	$("#abv_min").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 20, decimalDigits: 1, spinButtons: true, spinButtonsStep: 0.1 });
	$("#abv_max").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, max: 20, decimalDigits: 1, spinButtons: true, spinButtonsStep: 0.1 });

	$("#notes").jqxInput({ theme: theme, width: 640, height: 100 });
	$("#profile").jqxInput({ theme: theme, width: 640, height: 48 });
	$("#ingredients").jqxInput({ theme: theme, width: 640, height: 23 });
	$("#examples").jqxInput({ theme: theme, width: 640, height: 48 });
	var dataAdapter = new $.jqx.dataAdapter(source);
	var editrow = -1;
	// initialize jqxGrid
	$("#jqxgrid").jqxGrid({
		width: 1280,
		height: 630,
		source: dataAdapter,
		theme: theme,
		showstatusbar: true,
		localization: getLocalization(),
		renderstatusbar: function (statusbar) {
			var container = $("<div style='overflow: hidden; position: relative; margin: 5px;'></div>");
			var addButton = $("<div style='float: right; margin-right: 15px;'><img style='position: relative; margin-top: 2px;' src='images/add.png'/><span style='margin-left: 4px; position: relative; top: -3px;'>Add</span></div>");
			container.append(addButton);
			statusbar.append(container);
			addButton.jqxButton({  width: 60, height: 20 });
			// add new row.
			addButton.click(function (event) {
				editrow = -1;
				$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
				$("#name").val('');
				$("#category").val('');
				$("#category_number").val('');
				$("#style_letter").val('');
				$("#style_guide").val('');
				$("#type").val('');
				$("#og_min").val('');
				$("#og_max").val('');
				$("#fg_min").val('');
				$("#fg_max").val('');
				$("#ibu_min").val('');
				$("#ibu_max").val('');
				$("#color_min").val('');
				$("#color_max").val('');
				$("#carb_min").val('');
				$("#carb_max").val('');
				$("#abv_min").val('');
				$("#abv_max").val('');
				$("#notes").val('');
				$("#profile").val('');
				$("#ingredients").val('');
				$("#examples").val('');
				$("#popupWindow").jqxWindow('open');
			});
		},
		filterable: true,
		filtermode: 'excel',
		columns: [
			{ text: 'Groep', datafield: 'style_letter', width: 30 },
			{ text: 'Style Name', datafield: 'name', width: 250 },
			{ text: 'OG', datafield: 'og_min', width: 60, cellsalign: 'right', cellsformat: 'f3' },
			{ text: 'OG', datafield: 'og_max', width: 60, cellsalign: 'right', cellsformat: 'f3' },
			{ text: 'FG', datafield: 'fg_min', width: 60, cellsalign: 'right', cellsformat: 'f3' },
			{ text: 'FG', datafield: 'fg_max', width: 60, cellsalign: 'right', cellsformat: 'f3' },
			{ text: 'IBU', datafield: 'ibu_min', width: 60, cellsalign: 'right', cellsformat: 'f0' },
			{ text: 'IBU', datafield: 'ibu_max', width: 60, cellsalign: 'right', cellsformat: 'f0' },
			{ text: 'EBC', datafield: 'color_min', width: 60, cellsalign: 'right', cellsformat: 'f0' },
			{ text: 'EBC', datafield: 'color_max', width: 60, cellsalign: 'right', cellsformat: 'f0' },
			{ text: 'Co2', datafield: 'carb_min', width: 60, cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Co2', datafield: 'carb_max', width: 60, cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'ABV', datafield: 'abv_min', width: 60, cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'ABV', datafield: 'abv_max', width: 60, cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Edit', datafield: 'Edit', columntype: 'button', cellsrenderer: function () {
				return "Edit";
				}, buttonclick: function (row) {
					// open the popup window when the user clicks a button.
					editrow = row;
					$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
					// get the clicked row's data and initialize the input fields.
					var dataRecord = $("#jqxgrid").jqxGrid('getrowdata', editrow);
					$("#name").val(dataRecord.name);
					$("#category").val(dataRecord.category);
					$("#category_number").val(dataRecord.category_number);
					$("#style_letter").val(dataRecord.style_letter);
					$("#style_guide").val(dataRecord.style_guide);
					$("#type").val(dataRecord.type);
					$("#og_min").val(dataRecord.og_min);
					$("#og_max").val(dataRecord.og_max);
					$("#fg_min").val(dataRecord.fg_min);
					$("#fg_max").val(dataRecord.fg_max);
					$("#ibu_min").val(dataRecord.ibu_min);
					$("#ibu_max").val(dataRecord.ibu_max);
					$("#color_min").val(dataRecord.color_min);
					$("#color_max").val(dataRecord.color_max);
					$("#carb_min").val(dataRecord.carb_min);
					$("#carb_max").val(dataRecord.carb_max);
					$("#abv_min").val(dataRecord.abv_min);
					$("#abv_max").val(dataRecord.abv_max);
					$("#notes").val(dataRecord.notes);
					$("#profile").val(dataRecord.profile);
					$("#ingredients").val(dataRecord.ingredients);
					$("#examples").val(dataRecord.examples);
					// show the popup window.
					$("#popupWindow").jqxWindow('open');
				}
			}
		]
	});
	// initialize the popup window and buttons.
	$("#popupWindow").jqxWindow({
		width: 860, resizable: false, theme: theme, isModal: true, autoOpen: false, cancelButton: $("#Cancel"), modalOpacity: 0.40           
	});
	$("#popupWindow").on('open', function () {
		$("#name").jqxInput('selectAll');
	});
	$("#Delete").jqxButton({ theme: theme });
	$("#Delete").click(function () {
		if (editrow >= 0) {
			// Open a popup to confirm this action.
			$('#eventWindow').jqxWindow('open');
			$("#delOk").click(function () {
				var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
				$("#jqxgrid").jqxGrid('deleterow', rowID);
			});
		}
		$("#popupWindow").jqxWindow('hide');
	});
	$("#Cancel").jqxButton({ theme: theme });
	$("#Save").jqxButton({ theme: theme });
	// update the edited row when the user clicks the 'Save' button.
	$("#Save").click(function () {
		if (editrow >= 0) {
			var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
			var row = {
				record: rowID,
				name: $("#name").val(),
				category: $("#category").val(),
				category_number: parseFloat($("#category_number").jqxNumberInput('decimal')),
				style_letter: $("#style_letter").val(),
				style_guide: $("#style_guide").val(),
				type: $("#type").val(),
				og_min: parseFloat($("#og_min").jqxNumberInput('decimal')),
				og_max: parseFloat($("#og_max").jqxNumberInput('decimal')),
				fg_min: parseFloat($("#fg_min").jqxNumberInput('decimal')),
				fg_max: parseFloat($("#fg_max").jqxNumberInput('decimal')),
				ibu_min: parseFloat($("#ibu_min").jqxNumberInput('decimal')),
				ibu_max: parseFloat($("#ibu_max").jqxNumberInput('decimal')),
				color_min: parseFloat($("#color_min").jqxNumberInput('decimal')),
				color_max: parseFloat($("#color_max").jqxNumberInput('decimal')),
				carb_min: parseFloat($("#carb_min").jqxNumberInput('decimal')),
				carb_max: parseFloat($("#carb_max").jqxNumberInput('decimal')),
				abv_min: parseFloat($("#abv_min").jqxNumberInput('decimal')),
				abv_max: parseFloat($("#abv_max").jqxNumberInput('decimal')),
				notes: $("#notes").val(),
				profile: $("#profile").val(),
				ingredients: $("#ingredients").val(),
				examples: $("#examples").val()
			};
			$('#jqxgrid').jqxGrid('updaterow', rowID, row);
			$("#popupWindow").jqxWindow('hide');
		} else {
			// Insert a record
			var newrow = {
				record: -1,
				name: $("#name").val(),
				category: $("#category").val(),
				category_number: parseFloat($("#category_number").jqxNumberInput('decimal')),
				style_letter: $("#style_letter").val(),
				style_guide: $("#style_guide").val(),
				type: $("#type").val(),
				og_min: parseFloat($("#og_min").jqxNumberInput('decimal')),
				og_max: parseFloat($("#og_max").jqxNumberInput('decimal')),
				fg_min: parseFloat($("#fg_min").jqxNumberInput('decimal')),
				fg_max: parseFloat($("#fg_max").jqxNumberInput('decimal')),
				ibu_min: parseFloat($("#ibu_min").jqxNumberInput('decimal')),
				ibu_max: parseFloat($("#ibu_max").jqxNumberInput('decimal')),
				color_min: parseFloat($("#color_min").jqxNumberInput('decimal')),
				color_max: parseFloat($("#color_max").jqxNumberInput('decimal')),
				carb_min: parseFloat($("#carb_min").jqxNumberInput('decimal')),
				carb_max: parseFloat($("#carb_max").jqxNumberInput('decimal')),
				abv_min: parseFloat($("#abv_min").jqxNumberInput('decimal')),
				abv_max: parseFloat($("#abv_max").jqxNumberInput('decimal')),
				notes: $("#notes").val(),
				profile: $("#profile").val(),
				ingredients: $("#ingredients").val(),
				examples: $("#examples").val()
			};
			$('#jqxgrid').jqxGrid('addrow', null, newrow);
			$("#popupWindow").jqxWindow('hide');
		}
	});
	createDelElements();
});

